.. django-mongonaut documentation master file, created by
   sphinx-quickstart on Mon Jan  2 09:26:02 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-mongonaut's documentation!
============================================

An introspective interface for Django and MongoDB. Built from scratch to replicate some of the Django admin functionality, but for MongoDB.

Contents:

.. toctree::
   :maxdepth: 2
   
   installation
   usage
   future_usage   

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

